@@ -11,5 +11,4 @@ class tax(Variable):
 
     def formula(person, period, parameters):
         market_income = person("market_income", period)
-        tax_rate = parameters(period).tax_rate
-        return market_income * tax_rate
+        return parameters(period).gov.tax_rate.calc(market_income)
